==> peperit_2.0_estable.zip: themes/peperit/theme_config.php <==
<?php
	//07/Abril/2020 ==> Creamos el fichero
	//04/Mayo/2020 ==> Añadimos el tema padre
	//A día de hoy en peperit tenemos ciertos elementos "configurables"
	//--------------------------------------------------------------
	// --> tema padre
	//Theme::setConfigParam('masterTheme', 'peperit'); ==> Peperit NO tiene padre

	//A día de hoy en peperit tenemos ciertos elementos "configurables"
	//--------------------------------------------------------------
	// --> Cabecera
		//Posibilidades: {cabeceraUno.php, cabeceraDos.php, cabeceraTres.php, cabeceraCuatro.php, cabeceraCinco.php, cabeceraSeis.php}
	Theme::setConfigParam('cabecera', 'cabeceraUno.php');
	// --> Fichero con el menú de cabecera
		//Posibilidades: {menuCategoriasHamburguesa.php, menuCategoriasDesplegado.php, menuCategoriasHamburguesaSolo.php}
	Theme::setConfigParam('menuSuperior', 'menuCategoriasHamburguesa.php');
	// --> Fichero la cesta desplegable
		//Posibilidades: {cestaDesplegable.php}
	Theme::setConfigParam('cestaDesplegable', 'cestaDesplegable.php');
	
	//--------------------------------------------------------------
	// --> ficha pequeña en resultado de búsquedas
	Theme::setConfigParam('fichaPeqBusqueda', 'mini_ficha_semaforo.php');
	
	//--------------------------------------------------------------
	// --> ficha pequeña en escaparates
	Theme::setConfigParam('fichaPeqEscaparate', 'mini_ficha_semaforo.php');

	//--------------------------------------------------------------
	// --> ficha ampliada
	Theme::setConfigParam('fichaAmpliada', 'ficha_ampliada_relacionados_aside.php');
	
	//--------------------------------------------------------------
	// --> footer
	Theme::setConfigParam('pie', 'plantilla_footer.php');
	
	//--------------------------------------------------------------
	// --> La plantilla tiene blog
	Theme::setConfigParam('hasBlog', false);
	// --> Mostramos los utimos posts
	Theme::setConfigParam('ultimosPosts', false);
	
	//--------------------------------------------------------------
	// --> habilitamos el orden de productos y productos por página
	Theme::setConfigParam('productsOrder', false);
	
	//--------------------------------------------------------------
	// --> habilitamos el filtrado de productos
	Theme::setConfigParam('filterProducts', false);
	
	//--------------------------------------------------------------
	// --> habilitamos las categoráis en el aside
	Theme::setConfigParam('asideShowCategories', false);
	
	//--------------------------------------------------------------
	// --> web boxed (container) o full-width (container-fluid)
		//Posibilidades: {container, container-fluid}
	Theme::setConfigParam('container_style', 'container');

==> peperit_2.1.01_estable.zip: themes/peperit/theme_config.php <==
<?php
	//07/Abril/2020 ==> Creamos el fichero
	//04/Mayo/2020 ==> Añadimos el tema padre
	//A día de hoy en peperit tenemos ciertos elementos "configurables"
	//--------------------------------------------------------------
	// --> tema padre
	//Theme::setConfigParam('masterTheme', 'peperit'); //==> Peperit NO tiene padre

	//A día de hoy en peperit tenemos ciertos elementos "configurables"
	//--------------------------------------------------------------
	// --> Cabecera
		//Posibilidades: {cabeceraUno.php, cabeceraDos.php, cabeceraTres.php, cabeceraCuatro.php, cabeceraCinco.php, cabeceraSeis.php}
	Theme::setConfigParam('cabecera', 'cabeceraUno.php');
	// --> Fichero con el menú de cabecera
		//Posibilidades: {menuCategoriasHamburguesa.php, menuCategoriasDesplegado.php, menuCategoriasHamburguesaSolo.php}
	Theme::setConfigParam('menuSuperior', 'menuCategoriasHamburguesa.php');
	// --> Fichero la cesta desplegable
		//Posibilidades: {cestaDesplegable.php}
	Theme::setConfigParam('cestaDesplegable', 'cestaDesplegable.php');
	
	//--------------------------------------------------------------
	// --> ficha pequeña en resultado de búsquedas
	Theme::setConfigParam('fichaPeqBusqueda', 'mini_ficha_semaforo.php');
	
	//--------------------------------------------------------------
	// --> ficha pequeña en escaparates
	Theme::setConfigParam('fichaPeqEscaparate', 'mini_ficha_semaforo.php');

	//--------------------------------------------------------------
	// --> ficha ampliada
	Theme::setConfigParam('fichaAmpliada', 'ficha_ampliada_relacionados_aside.php');
	
	//--------------------------------------------------------------
	// --> footer
	Theme::setConfigParam('pie', 'plantilla_footer.php');
	
	//--------------------------------------------------------------
	// --> La plantilla tiene blog
	Theme::setConfigParam('hasBlog', false);
	// --> Mostramos los utimos posts
	Theme::setConfigParam('ultimosPosts', false);
	
	//--------------------------------------------------------------
	// --> habilitamos el orden de productos y productos por página
	Theme::setConfigParam('productsOrder', false);
	
	//--------------------------------------------------------------
	// --> habilitamos el filtrado de productos
	Theme::setConfigParam('filterProducts', false);
	
	//--------------------------------------------------------------
	// --> habilitamos las categoráis en el aside
	Theme::setConfigParam('asideShowCategories', false);
	
	//--------------------------------------------------------------
	// --> web boxed (container) o full-width (container-fluid)
		//Posibilidades: {container, container-fluid}
	Theme::setConfigParam('container_style', 'container');
	
	//--------------------------------------------------------------
	// --> Posición del paginador top|bottom|top,bottom
	Theme::setConfigParam('pagerPosition', 'bottom');
